==> igloo_0_1_3.zip: igloo_0_1_3/igloo/language/1/barnraiser_01/arrays/arr_homepage.lang.php <==
<?php

// -----------------------------------------------------------------------
// This file is part of Igloo
//
// Copyright (C) 2003, 2005 Barnraiser
// http://www.barnraiser.org/
// info@barnraiser.org
//
// This program is free software; you can redistribute it and/or modify it
// under the terms of the GNU General Public License as published by the
// Free Software Foundation; either version 2, or (at your option) any
// later version.
//
// This program is distributed in the hope that it will be useful, but
// WITHOUT ANY WARRANTY; without even the implied warranty of
// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
// General Public License for more details.
//
// You should have received a copy of the GNU General Public License
// along with program; see the file COPYING. If not, write to the Free
// Software Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA
// 02110-1301, USA.
// -----------------------------------------------------------------------
// Tom Calthrop - 20th April 2004 (tom@barnraiser.org)



// HOMEPAGE -------------------------------------------------
$lang['homepage']['page'][1] = 							"spl_view.php";
$lang['homepage']['page'][2] = 							"mag_view.php";
$lang['homepage']['page'][3] = 							"msg_view.php";
$lang['homepage']['page'][4] = 							"my_membership.php";
$lang['homepage']['page'][5] = 							"sch_view.php";
$lang['homepage']['page'][6] = 							"sn_list.php";

$lang['homepage']['page_desc'][1] = 					"Splash page";
$lang['homepage']['page_desc'][2] = 					"Stuff page";
$lang['homepage']['page_desc'][3] = 					"Message inbox";
$lang['homepage']['page_desc'][4] = 					"Account page";
$lang['homepage']['page_desc'][5] = 					"My schedule";
$lang['homepage']['page_desc'][6] = 					"Social network";

?>

==> igloo_0_1_7.zip: igloo_0_1_7/igloo/language/1/barnraiser_01/arrays/arr_homepage.lang.php <==
<?php

// -----------------------------------------------------------------------
// This file is part of Igloo
//
// Copyright (C) 2003, 2006 Barnraiser
// http://www.barnraiser.org/
// info@barnraiser.org
//
// This program is free software; you can redistribute it and/or modify it
// under the terms of the GNU General Public License as published by the
// Free Software Foundation; either version 2, or (at your option) any
// later version.
//
// This program is distributed in the hope that it will be useful, but
// WITHOUT ANY WARRANTY; without even the implied warranty of
// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
// General Public License for more details.
//
// You should have received a copy of the GNU General Public License
// along with program; see the file COPYING. If not, write to the Free
// Software Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA
// 02110-1301, USA.
// -----------------------------------------------------------------------
// Tom Calthrop - 20th April 2004 (tom@barnraiser.org)



// HOMEPAGE -------------------------------------------------
$lang['homepage']['page'][1] = 							"spl_view.php";
$lang['homepage']['page'][2] = 							"mag_view.php";
$lang['homepage']['page'][3] = 							"msg_view.php";
$lang['homepage']['page'][4] = 							"my_membership.php";
$lang['homepage']['page'][5] = 							"sch_view.php";
$lang['homepage']['page'][6] = 							"sn_list.php";

$lang['homepage']['page_desc'][1] = 					"Start page";
$lang['homepage']['page_desc'][2] = 					"Group page";
$lang['homepage']['page_desc'][3] = 					"Message inbox";
$lang['homepage']['page_desc'][4] = 					"Account page";
$lang['homepage']['page_desc'][5] = 					"My schedule";
$lang['homepage']['page_desc'][6] = 					"Social network";

?>
